summaryrefslogtreecommitdiffstats
path: root/examples/opengl
diff options
context:
space:
mode:
authorQt Forward Merge Bot <qt_forward_merge_bot@qt-project.org>2019-05-12 01:00:07 +0200
committerQt Forward Merge Bot <qt_forward_merge_bot@qt-project.org>2019-05-12 01:00:08 +0200
commitf8212b87d9b9474eaba2493662ef6c2d2e7a4376 (patch)
treee3d56ef186ef2004892ee4f446a36de308ac39e4 /examples/opengl
parent591116490cf313808e8ba05ddd066656a1d1a566 (diff)
parent45aa3c73f78c6c06874d0f826e1f112976cd522d (diff)
Merge remote-tracking branch 'origin/5.12' into 5.13
Diffstat (limited to 'examples/opengl')
-rw-r--r--examples/opengl/hellogles3/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/opengl/hellogles3/main.cpp b/examples/opengl/hellogles3/main.cpp
index 29b3b9617a..9451b2882f 100644
--- a/examples/opengl/hellogles3/main.cpp
+++ b/examples/opengl/hellogles3/main.cpp
@@ -69,11 +69,11 @@ int main(int argc, char *argv[])
QSurfaceFormat fmt;
fmt.setDepthBufferSize(24);
// Request OpenGL 3.3 compatibility or OpenGL ES 3.0.
if (QOpenGLContext::openGLModuleType() == QOpenGLContext::LibGL) {
- qDebug("Requesting 3.3 compatibility context");
+ qDebug("Requesting 3.3 core context");
fmt.setVersion(3, 3);
- fmt.setProfile(QSurfaceFormat::CompatibilityProfile);
+ fmt.setProfile(QSurfaceFormat::CoreProfile);
} else {
qDebug("Requesting 3.0 context");
fmt.setVersion(3, 0);
@@ -69,11 +69,11 @@ int main(int argc, char *argv[])
QSurfaceFormat fmt;
fmt.setDepthBufferSize(24);
- // Request OpenGL 3.3 compatibility or OpenGL ES 3.0.
+ // Request OpenGL 3.3 core or OpenGL ES 3.0.
if (QOpenGLContext::openGLModuleType() == QOpenGLContext::LibGL) {